/*
 * settzscreen.h - Screen for setting the timezone
 * Copyright (C) 2024  Alexander Rosenberg
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version. See the LICENSE file for more information.
 */
#ifndef INCLUDED_SETTZSCREEN_H
#define INCLUDED_SETTZSCREEN_H

#include "screen.h"

typedef struct {
    int hour;
    int minute;
    int second;
} TZOffset;

#define tz_offset_reset(o) ((o)->hour = (o)->minute = (o)->second = 0)

typedef struct {
    enum {
        DST_BOUND_EXACT_JULIAN = 0,
        DST_BOUND_LEAP_JULAIN,
        DST_BOUND_MND,
    } type;
    union {
        struct {
            int month;
            int week;
            int day;
        };
        int julian_day;
    };
    TZOffset time;
} DSTBound;

typedef enum {
    TZ_OFFSET_SEL_HOUR,
    TZ_OFFSET_SEL_MINUTE,
    TZ_OFFSET_SEL_SECOND,
} TZOffsetSelectStage;

typedef enum {
    DST_BOUND_SEL_TYPE,
    DST_BOUND_SEL_MONTH,
    DST_BOUND_SEL_WEEK,
    DST_BOUND_SEL_DAY,
    DST_BOUND_SEL_JULIAN,
    DST_BOUND_SEL_TIME,
} DSTBoundSelectStage;

typedef enum {
    SET_TZ_BACK,
    SET_TZ_CONTINUE,
    SET_TZ_NEXT,
} SetTZScreenAction;

typedef struct {
    Screen parent;
    enum {
        SET_TZ_OFFSET,
        SET_TZ_HAS_DST,
        SET_TZ_DST_OFFSET,
        SET_TZ_DST_START,
        SET_TZ_DST_END,
        SET_TZ_FINISH,
    } stage;
    bool need_redraw;
    TZOffsetSelectStage off_sel_stage;
    DSTBoundSelectStage bound_sel_stage;
    int julian_didgit;
    TZOffset offset;
    bool has_dst;
    TZOffset dst_offset;
    DSTBound start_bound;
    DSTBound end_bound;
    bool did_set;
} SetTZScreen;

/*
 * Create a new SetTZScreen that will allow the user the set the time zone.
 */
SetTZScreen *set_tz_screen_new(void);

#endif
